@@ -144,7 +144,7 @@ class Imposter(JsonSerializable):
         post = requests.post(f"{self.configuration_url}/stubs", json=json, timeout=10)
         post.raise_for_status()
         self.stubs.append(definition)  # TODO - what if we've not added to the end?
-        return index if index else len(post.json()["stubs"]) - 1
+        return index or len(post.json()["stubs"]) - 1
 
     def delete_stub(self, index: int) -> Stub:
         """Remove a stub from a running impostor."""
@@ -152,6 +152,13 @@ class Imposter(JsonSerializable):
         post.raise_for_status()
         return self.stubs.pop(index)
 
+    def update_stub(self, index: int, definition: Stub) -> int:
+        """Change a stub in an existing imposter. Returns index of changed stub."""
+        json = definition.as_structure()
+        put = requests.put(f"{self.configuration_url}/stubs/{index}", json=json, timeout=10)
+        put.raise_for_status()
+        return index
+
 
 class Request(metaclass=ABCMeta):
     @staticmethod
@@ -212,7 +219,7 @@ class SentEmail(Request):
         email: Mapping[str, Union[str, Sequence[Address]]] = {
             SentEmail._map_key(k): SentEmail._translate_value(v) for k, v in json.items()
         }
-        sent_email = SentEmail(**email)
+        sent_email = SentEmail(**email)  # type: ignore
         return sent_email
 
     @staticmethod
@@ -231,5 +238,5 @@ class SentEmail(Request):
 def smtp_imposter(name="smtp", record_requests=True) -> Imposter:
     """Canned SMTP server imposter."""
     return Imposter(
-        [], 4525, protocol=Imposter.Protocol.SMTP, name=name, record_requests=record_requests
+        [], 5525, protocol=Imposter.Protocol.SMTP, name=name, record_requests=record_requests
     )
