@@ -14,7 +14,7 @@ from mbtest.imposters.predicates import Predicate
 
 class BaseResponse(JsonSerializable, metaclass=ABCMeta):
     @classmethod
-    def from_structure(cls, structure: JsonStructure) -> "BaseResponse":
+    def from_structure(cls, structure: JsonStructure) -> "BaseResponse":  # noqa: C901
         if "is" in structure and "_behaviors" in structure:
             return Response.from_structure(structure)
         elif "is" in structure and "data" in structure["is"]:
@@ -23,6 +23,8 @@ class BaseResponse(JsonSerializable, metaclass=ABCMeta):
             return Proxy.from_structure(structure)
         elif "inject" in structure:
             return InjectionResponse.from_structure(structure)
+        elif "fault" in structure:
+            return FaultResponse.from_structure(structure)
         raise NotImplementedError()  # pragma: no cover
 
 
@@ -115,10 +117,8 @@ class Response(BaseResponse):
         *,
         http_response: Optional[HttpResponse] = None,
     ) -> None:
-        self.http_response = (
-            http_response
-            if http_response
-            else HttpResponse(body=body, status_code=status_code, headers=headers, mode=mode)
+        self.http_response = http_response or HttpResponse(
+            body=body, status_code=status_code, headers=headers, mode=mode
         )
         # TODO: Deprecate HttpResponse arguments
         self.wait = wait
@@ -190,6 +190,28 @@ class TcpResponse(BaseResponse):
         return cls(data=structure["is"]["data"])
 
 
+class FaultResponse(BaseResponse):
+    """Represents a `Mountebank fault response <https://www.mbtest.org/docs/api/faults>`_.
+
+    :param fault: The fault to simulate.
+    """
+
+    class Fault(Enum):
+        CONNECTION_RESET_BY_PEER = "CONNECTION_RESET_BY_PEER"
+        RANDOM_DATA_THEN_CLOSE = "RANDOM_DATA_THEN_CLOSE"
+
+    def __init__(self, fault: Fault) -> None:
+        self.fault = fault
+
+    def as_structure(self) -> JsonStructure:
+        return {"fault": self.fault.name}
+
+    @classmethod
+    def from_structure(cls, structure: JsonStructure) -> "FaultResponse":
+        fault = cls.Fault(structure["fault"])
+        return cls(fault=fault)
+
+
 class Proxy(BaseResponse):
     """Represents a `Mountebank proxy <http://www.mbtest.org/docs/api/proxies>`_.
 
@@ -221,7 +243,7 @@ class Proxy(BaseResponse):
 
     def as_structure(self) -> JsonStructure:
         proxy = {
-            "to": self.to.url if isinstance(self.to, furl) else self.to,
+            "to": furl(self.to).url,
             "mode": self.mode.value,
         }
         self.add_if_true(proxy, "injectHeaders", self.inject_headers)
@@ -262,12 +284,21 @@ class Proxy(BaseResponse):
 
 
 class PredicateGenerator(JsonSerializable):
+    """Represents a `Mountebank predicate generator <https://www.mbtest.org/docs/api/proxies#proxy-predicate-generators>`_.
+
+    :param path: Include the path in the generated predicate.
+    """
+
     def __init__(
         self,
         path: bool = False,
         query: Union[bool, Mapping[str, str]] = False,
+        # method: bool = False,
+        # body: bool = False,
+        # headers: Union[bool, Mapping[str, str]] = False,
         operator: Predicate.Operator = Predicate.Operator.EQUALS,
         case_sensitive: bool = True,
+        # ignore_query: bool = False,
     ):
         self.path = path
         self.query = query
